EXTENSIONS = [
    ".h5",
    ".hdf5",
    ".yaml",
    ".yml",
    ".pt",
    ".pb",
    ".pkl",
    ".ckpt",
    ".pickle",
]

TAGS_KEY = ["tasks", "libraries", "embeddings", "datasets", "device"]
